# Data Privacy Statement: SAP LeanIX Workspace
### On this page
  * [1. Purpose and scope](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace#1.-purpose-and-scope)
  * [2. Data Controller](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace#2.-data-controller)
  * [3. Scope of Processing](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace#3.-scope-of-processing)
  * [4. The Rights of Users](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace#4.-the-rights-of-users)
  * [5. Additional information about Data collection and processing](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace#5.-additional-information-about-data-collection-and-processing)


Data privacy statement for SAP LeanIX workspaces.
